@@ -381,6 +381,8 @@ def copy_singlefile_from_archive(scrfile_path, dstfile_path):
 def read_raster_info(raster_filepath):
     ds = gdal.Open(str(raster_filepath))
 
+    RasterXSize = ds.RasterXSize
+    RasterYSize = ds.RasterYSize
     gt = ds.GetGeoTransform()
     ulx_raster = gt[0]
     uly_raster = gt[3]
@@ -398,7 +400,7 @@ def read_raster_info(raster_filepath):
     n_bands = ds.RasterCount
     epsg = ds.GetSpatialRef().GetAuthorityCode(None)
     ds = None
-    return (xmin, ymax, ds.RasterXSize, ds.RasterYSize, pixel_width, projection, epsg, datatype, n_bands, imagery_extent_box)
+    return (xmin, ymax, RasterXSize, RasterYSize, pixel_width, projection, epsg, datatype, n_bands, imagery_extent_box)
 
 
 def reproject_multibandraster_toextent(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
